@@ -27,4 +27,4 @@ man_pages = [
 # Bibliographic Dublin Core info.
 epub_title = u'GNATcoll Bindings - Readline'
 
-execfile('../../docs-common/common_conf.py')
+exec(open('../../docs-common/common_conf.py').read())
